==> was-plugin-10.1.0-331.113.jar: was/env/discover-inspect-string-namespacebinding.py <==
#  Override function from was/runtime/base.py
def inspectAdminConfigPropertiesCallback(container,prototype, canHandleAdminConfigPropertyTypeCallback, adminConfigPropertyTypeInspectCallback, listObjectsInContainerCallback=None):
    print "Retrieving list of %s objects in container %s" % (prototype.wasType, container.name)
    if listObjectsInContainerCallback:
        AdminConfigPropertiesList = listObjectsInContainerCallback(container, prototype)
    else:
        AdminConfigPropertiesList = wsadminToList(AdminConfig.list(prototype.wasType, AdminConfig.getid(container.containmentPath)))
    for prop in AdminConfigPropertiesList:
        if canHandleAdminConfigPropertyTypeCallback is None or canHandleAdminConfigPropertyTypeCallback(p):
            # protect XLD ids by replacing slash with underscore
            name = AdminConfig.showAttribute(prop, 'name').replace("/","_")
            print "Discovered %s %s in container %s" % (prototype.type, name, container.name)
            deployedId = container.id + '/' + name
            discovered(deployedId, prototype.type)
            adminConfigPropertyTypeInspectCallback(deployedId, name, prop, prototype)
            inspectedItem(deployedId)

def listNamespaceBindings(container, prototype):
    return wsadminToList(AdminConfig.getid('%s/%s:/' % (container.containmentPath, prototype.wasType)))

def inspectNamespaceBinding(deployedId, deployedName, resourceId, prototype):
    inspectDeployedProperties(deployedId, deployedName, resourceId, prototype)
    # discover new bindingIdentifier property in CI
    inspectedProperty(deployedId, 'bindingIdentifier', AdminConfig.showAttribute(resourceId, 'name'))
    inspectedProperty(deployedId, 'value', AdminConfig.showAttribute(resourceId, 'stringToBind'))

discoverAndInspectResources(container, prototype, listNamespaceBindings, inspectNamespaceBinding)

==> was-plugin-22.0.0.jar: was/env/discover-inspect-string-namespacebinding.py <==
#  Override function from was/runtime/base.py
def inspectAdminConfigPropertiesCallback(container,prototype, canHandleAdminConfigPropertyTypeCallback, adminConfigPropertyTypeInspectCallback, listObjectsInContainerCallback=None, appendTypeToName=False):
    print "Retrieving list of %s objects in container %s" % (prototype.wasType, container.name)
    if listObjectsInContainerCallback:
        AdminConfigPropertiesList = listObjectsInContainerCallback(container, prototype)
    else:
        AdminConfigPropertiesList = wsadminToList(AdminConfig.list(prototype.wasType, AdminConfig.getid(container.containmentPath)))
    for prop in AdminConfigPropertiesList:
        if canHandleAdminConfigPropertyTypeCallback is None or canHandleAdminConfigPropertyTypeCallback(p):
            # protect XLD ids by replacing slash with underscore
            name = AdminConfig.showAttribute(prop, 'name').replace("/","_")
            print "Discovered %s %s in container %s" % (prototype.type, name, container.name)

            if appendTypeToName:
                deployedId = container.id + '/' + name + '_' + prototype.type
            else:
                deployedId = container.id + '/' + name
            discovered(deployedId, prototype.type)
            inspectedProperty(deployedId, 'wasName', name)
            adminConfigPropertyTypeInspectCallback(deployedId, name, prop, prototype)
            inspectedItem(deployedId)

def listNamespaceBindings(container, prototype):
    return wsadminToList(AdminConfig.getid('%s/%s:/' % (container.containmentPath, prototype.wasType)))

def inspectNamespaceBinding(deployedId, deployedName, resourceId, prototype):
    inspectDeployedProperties(deployedId, deployedName, resourceId, prototype)
    # discover new bindingIdentifier property in CI
    inspectedProperty(deployedId, 'bindingIdentifier', AdminConfig.showAttribute(resourceId, 'name'))
    inspectedProperty(deployedId, 'value', AdminConfig.showAttribute(resourceId, 'stringToBind'))

discoverAndInspectResources(container, prototype, listNamespaceBindings, inspectNamespaceBinding, appendTypeToName)
